@@ -7,6 +7,8 @@
 
 #include "phonepanel.h"
 
+K_PLUGIN_CLASS_WITH_JSON(PhonePanel, "metadata.json")
+
 PhonePanel::PhonePanel(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Containment(parent, data, args)
 {
@@ -14,6 +16,4 @@ PhonePanel::PhonePanel(QObject *parent, const KPluginMetaData &data, const QVari
 
 PhonePanel::~PhonePanel() = default;
 
-K_PLUGIN_CLASS(PhonePanel)
-
 #include "phonepanel.moc"
